@@ -1,5 +1,5 @@
 mono <- 
-function(object, which = c("left", "right")){
+function(object, which = c("left", "right", "both")){
     if(!is(object, "Wave")) 
         stop("Object not of class 'Wave'")
     validObject(object)
@@ -16,6 +16,12 @@ function(object, which = c("left", "right")){
                 object@stereo <- FALSE
                 object@right <- numeric(0)
                 object
+            },
+            both = {
+                object@left <- (object@right + object@left) / 2
+                object@stereo <- FALSE
+                object@right <- numeric(0)
+                object
             }
         )
     )
